#!/bin/bash
### KWProject:
KWProj=CSG_SEC_SW_1_0_Linux_TXEI
URL="https://fm6gapp664.amr.corp.intel.com:8080"

### GET Timestamp
TimeStamp=`date +%Y%m%d%H%M%S`
KWBuild=${1:-${TimeStamp}}

### The acutal build command to which KW Need to eavsdrop
#RawBuildCommand=build.sh
RawBuildCommand=make


### Select Root direcroty so that desktop analysis will be relative to it.
KW_SRC_ROOT=${PWD}

#### Prepape the workarea
KLOCWORK_WORKAREA="KW"

mkdir -p ${KLOCWORK_WORKAREA}/Tables

#### Trace a SKU build

echo `date +%R:%S` Tracing the build...

pushd .  >/dev/null
rm -f -R bin 2>&1 > /dev/null
kwinject --trace-out ${KLOCWORK_WORKAREA}/kwtrace.out ${RawBuildCommand} > ${KLOCWORK_WORKAREA}/kwtrace.log 2>&1
if [ "${?}" -ne "0" ]
then
    exit 1
fi

popd >/dev/null

#### Post-Processing

cd ${KLOCWORK_WORKAREA}
if [ "${?}" -ne "0" ]
then
    exit 1
fi

### Create a KM Buildspec out of the trace of the build
echo `date +%R:%S` Translateing the trace into a buildspec...
kwinject --trace-in kwtrace.out --output kwbuildspec.tpl --variable "kwpsroot=${KW_SRC_ROOT}" >kwspec.log 2>&1
if [ "${?}" -ne "0" ]
then
    exit 1
fi

### Scan
echo `date +%R:%S` Analyzing...
kwbuildproject --url ${URL}/${KWProj} kwbuildspec.tpl --tables-directory Tables --buildspec-variable "kwpsroot=${KW_SRC_ROOT}" --force --jobs-num 2 > kwbuild.log 2>&1


### Upload to server
echo `date +%R:%S` Uploading...
### Disable for testing
kwadmin --url ${URL} load ${KWProj} Tables --name ${KWBuild} --copy-sources > kwloadCS.log 2>&1


### The End
echo `date +%R:%S` Done.
exit 0
